// NF Quellenumschalter
//
// Erstellt von: Marcus Pool
// 
// www.Marcus-Pool.de
//
// Version 1.00
//
// Versionshistorie
// 0.00 - 12.10.2012 Start mit der Software
// 1.00 - 08.06.2013 Erste Version

#include <main.h>
#include <avr/eeprom.h>
#include <lcd.h>
#include <util/delay.h> 
#include <poti.h>
#include <LED.h>
#include <stdlib.h>
#include <string.h>
#include <lcd_spezial.h>
#include <i2cmaster.h>

extern uint16_t	EE_LED_status	EEMEM;	// I2C LED Status
extern uint8_t	EE_Ein1_Poti	EEMEM;	// Poti Ein 1 Wert
extern uint8_t	EE_Ein2_Poti	EEMEM;	// Poti Ein 2 Wert
extern uint8_t	EE_Ein3_Poti	EEMEM;	// Poti Ein 3 Wert
extern uint8_t	EE_Ein4_Poti	EEMEM;	// Poti Ein 4 Wert
extern uint8_t	EE_Aus1_Poti	EEMEM;	// Poti Aus 1 Wert
extern uint8_t	EE_Aus2_Poti	EEMEM;	// Poti Aus 2 Wert
extern uint8_t	EE_Aus3_Poti	EEMEM;	// Poti Aus 3 Wert
extern uint8_t	EE_Mute			EEMEM;	// Mute
extern uint8_t	EE_Taste		EEMEM;	// letzte gedrckte Taste

extern uint8_t	LED_aktiv; 				// Speicher fr den aktuellen Ein/Ausgang
extern uint8_t 	Taster;
extern uint8_t	Mute;
extern int8_t	Poti_wert;

extern unsigned int led_array[15];

///////////////////////////////////////////////////////////////////////////////
//
//	Initialisieren der selbstdefinierten Character fr Mute und Lautstrke
//
///////////////////////////////////////////////////////////////////////////////
void lcd_save_cg(const unsigned char *cg)
{
	int i= 0;                  //Byte counter
	lcd_command(0x40);         //CG-RAM Address = 0
	for(i= 0; i <64 ; i++)     //Write 64 Bytes of 8 characters
	{
		lcd_data(pgm_read_byte(&cg[i]));
	}
	lcd_command(0x80);         // Set DD-RAM Address = 0
}


///////////////////////////////////////////////////////////////////////////////
//
//	Initialisieren nach Einschalten
//
///////////////////////////////////////////////////////////////////////////////
void Init_AVR(void)
{
	int8_t i = 0;
	uint16_t temp  = 0;

	lcd_save_cg(Cursor);									// Speichern der selbstdefinierten Character
	temp = eeprom_read_word((uint16_t*)&EE_LED_status);		// LED Status laden
	if (temp == 0xFFFF)										// EEPROM noch nicht beschrieben
	{
		lcd_puts("Init");
		eeprom_write_byte((uint8_t*)&EE_Ein1_Poti, 0x00);	// Poti Ein 1 Wert zurcksetzen
		eeprom_write_byte((uint8_t*)&EE_Ein2_Poti, 0x00);	// Poti Ein 2 Wert zurcksetzen
		eeprom_write_byte((uint8_t*)&EE_Ein3_Poti, 0x00);	// Poti Ein 3 Wert zurcksetzen
		eeprom_write_byte((uint8_t*)&EE_Ein4_Poti, 0x00);	// Poti Ein 4 Wert zurcksetzen
		eeprom_write_byte((uint8_t*)&EE_Aus1_Poti, 0x00);	// Poti Aus 1 Wert zurcksetzen
		eeprom_write_byte((uint8_t*)&EE_Aus2_Poti, 0x00);	// Poti Aus 2 Wert zurcksetzen
		eeprom_write_byte((uint8_t*)&EE_Aus3_Poti, 0x00);	// Poti Aus 3 Wert zurcksetzen
		eeprom_write_byte((uint8_t*)&EE_Taste, 0x01);		// Taste 1 als Init
		eeprom_write_word((uint16_t*)&EE_LED_status, 0x2AAA);// LED
		eeprom_write_byte((uint8_t*)&EE_Mute, 0x00);		// deaktivierte Mute speichern
		potis_auf_null();									// Eingangs IC auf minimale Lautstrke
		Taster = 0;
	}
	else													// gespeicherte Werte laden
	{
		Mute = eeprom_read_byte((uint8_t*)&EE_Mute);		// Mute Funktion
		if (Mute == 0x01)									// Mute ist deaktiviert
		{
			//  alle LEDs auf rot
			for (i = 0; i <= 14; i=i+2)						// alle grnen LEDs aus
			led_array[i] = 0;
			for (i = 1; i <= 14; i=i+2)						// alle roten LEDs an
			led_array[i] = 1;
			lcd_home(); lcd_puts("Mute an ");
			potis_auf_null();								// Eingangs IC auf minimale Lautstrke
		}
		else												// Mute is aktiviert
		{
			Taster = eeprom_read_byte((uint8_t*)&EE_Taste); // letzte gedrckte Taste laden
			load_LED();										// laden der vormals aktivierten LEDs
			poti_werte_laden();								// Poti Werte aus EEPROM laden und per I2C ausgeben
		}
	}
	switch (Taster)
	{
		case 1:	lcd_puts("Ein 1   "); break;
		case 2:	lcd_puts("Ein 2   "); break;
		case 3:	lcd_puts("Ein 3   "); break;
		case 4:	lcd_puts("Ein PC  "); break;
		case 5:	lcd_puts("Aus 1   "); break;
		case 6:	lcd_puts("Aus 2   "); break;
		case 7:	lcd_puts("Aus PC  "); break;
	}
	if (Mute == 0x00)										// Mute aus
	{
		poti_anzeige(Poti_wert, Taster);
	}
	else
		lcd_home(); lcd_puts("Mute an ");
}
